# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from ..experimental import instance_manager_pb2 as src_dot_ray_dot_protobuf_dot_experimental_dot_instance__manager__pb2


class InstanceManagerServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetInstanceManagerState = channel.unary_unary(
                '/ray.rpc.autoscaler.InstanceManagerService/GetInstanceManagerState',
                request_serializer=src_dot_ray_dot_protobuf_dot_experimental_dot_instance__manager__pb2.GetInstanceManagerStateRequest.SerializeToString,
                response_deserializer=src_dot_ray_dot_protobuf_dot_experimental_dot_instance__manager__pb2.GetInstanceManagerStateReply.FromString,
                )
        self.UpdateInstanceManagerState = channel.unary_unary(
                '/ray.rpc.autoscaler.InstanceManagerService/UpdateInstanceManagerState',
                request_serializer=src_dot_ray_dot_protobuf_dot_experimental_dot_instance__manager__pb2.UpdateInstanceManagerStateRequest.SerializeToString,
                response_deserializer=src_dot_ray_dot_protobuf_dot_experimental_dot_instance__manager__pb2.UpdateInstanceManagerStateReply.FromString,
                )
        self.GetAvailableInstanceTypes = channel.unary_unary(
                '/ray.rpc.autoscaler.InstanceManagerService/GetAvailableInstanceTypes',
                request_serializer=src_dot_ray_dot_protobuf_dot_experimental_dot_instance__manager__pb2.GetAvailableInstanceTypesRequest.SerializeToString,
                response_deserializer=src_dot_ray_dot_protobuf_dot_experimental_dot_instance__manager__pb2.GetAvailableInstanceTypesResponse.FromString,
                )


class InstanceManagerServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetInstanceManagerState(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateInstanceManagerState(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAvailableInstanceTypes(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_InstanceManagerServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetInstanceManagerState': grpc.unary_unary_rpc_method_handler(
                    servicer.GetInstanceManagerState,
                    request_deserializer=src_dot_ray_dot_protobuf_dot_experimental_dot_instance__manager__pb2.GetInstanceManagerStateRequest.FromString,
                    response_serializer=src_dot_ray_dot_protobuf_dot_experimental_dot_instance__manager__pb2.GetInstanceManagerStateReply.SerializeToString,
            ),
            'UpdateInstanceManagerState': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateInstanceManagerState,
                    request_deserializer=src_dot_ray_dot_protobuf_dot_experimental_dot_instance__manager__pb2.UpdateInstanceManagerStateRequest.FromString,
                    response_serializer=src_dot_ray_dot_protobuf_dot_experimental_dot_instance__manager__pb2.UpdateInstanceManagerStateReply.SerializeToString,
            ),
            'GetAvailableInstanceTypes': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAvailableInstanceTypes,
                    request_deserializer=src_dot_ray_dot_protobuf_dot_experimental_dot_instance__manager__pb2.GetAvailableInstanceTypesRequest.FromString,
                    response_serializer=src_dot_ray_dot_protobuf_dot_experimental_dot_instance__manager__pb2.GetAvailableInstanceTypesResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'ray.rpc.autoscaler.InstanceManagerService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class InstanceManagerService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetInstanceManagerState(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ray.rpc.autoscaler.InstanceManagerService/GetInstanceManagerState',
            src_dot_ray_dot_protobuf_dot_experimental_dot_instance__manager__pb2.GetInstanceManagerStateRequest.SerializeToString,
            src_dot_ray_dot_protobuf_dot_experimental_dot_instance__manager__pb2.GetInstanceManagerStateReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateInstanceManagerState(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ray.rpc.autoscaler.InstanceManagerService/UpdateInstanceManagerState',
            src_dot_ray_dot_protobuf_dot_experimental_dot_instance__manager__pb2.UpdateInstanceManagerStateRequest.SerializeToString,
            src_dot_ray_dot_protobuf_dot_experimental_dot_instance__manager__pb2.UpdateInstanceManagerStateReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetAvailableInstanceTypes(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ray.rpc.autoscaler.InstanceManagerService/GetAvailableInstanceTypes',
            src_dot_ray_dot_protobuf_dot_experimental_dot_instance__manager__pb2.GetAvailableInstanceTypesRequest.SerializeToString,
            src_dot_ray_dot_protobuf_dot_experimental_dot_instance__manager__pb2.GetAvailableInstanceTypesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
